@@ -22,8 +22,8 @@ from datetime import datetime, timedelta
 from pathlib import Path
 
 import pandas as pd
-from openstef.data_classes.prediction_job import PredictionJobDataClass
 
+from openstef.data_classes.prediction_job import PredictionJobDataClass
 from openstef.pipeline.create_basecase_forecast import create_basecase_forecast_pipeline
 from openstef.tasks.utils.predictionjobloop import PredictionJobLoop
 from openstef.tasks.utils.taskcontext import TaskContext
@@ -74,7 +74,8 @@ def main(config=None, database=None):
 
     if database is None or config is None:
         raise RuntimeError(
-            "Please specifiy a configmanager and/or database connection object. These can be found in the openstef-dbc package."
+            "Please specifiy a configmanager and/or database connection object. These"
+            " can be found in the openstef-dbc package."
         )
 
     with TaskContext(taskname, config, database) as context:
